From: Bruce Momjian <pgman@candle.pha.pa.us>
To: Stefan Kaltenbrunner <stefan@kaltenbrunner.cc>
Cc: Qingqing Zhou <zhouqq@cs.toronto.edu>
Cc: pgsql-hackers@postgresql.org
Subject: Re: Test request for Stats collector performance improvement
Date: Fri, 16 Jun 2006 12:24:03 -0400 (EDT)
Message-ID: <200606161624.k5GGO3N03466@candle.pha.pa.us> (raw)
In-Reply-To: <4492D882.6030109@kaltenbrunner.cc>
Stefan Kaltenbrunner wrote:
> Bruce Momjian wrote:
> > OK, based on reports I have seen, generally stats_query_string adds 50%
> > to the total runtime of a "SELECT 1" query, and the patch reduces the
> > overhead to 25%.
>
> that is actually not true for both of the platforms(a slow OpenBSD
> 3.9/x86 and a very fast Linux/x86_64) I tested on. Both of them show
> virtually no improvement with the patch and even worst it causes
> considerable (negative) variance on at least the Linux box.
I see the results I suggested on OpenBSD that you reported.
> OpenBSD 3.9-current/x86:
>
> without stats:
> 0m6.79s real 0m1.56s user 0m1.12s system
>
> -HEAD + stats:
> 0m10.44s real 0m2.26s user 0m1.22s system
>
> -HEAD + stats + patch:
> 0m10.68s real 0m2.16s user 0m1.36s system
and I got similar results reported from a Debian:
Linux 2.6.16 on a single processor HT 2.8Ghz Pentium compiled
with gcc 4.0.4.
> > real 0m3.306s
> > real 0m4.905s
> > real 0m4.448s
I am unclear on the cuase for the widely varying results you saw in
Debian.
--
Bruce Momjian http://candle.pha.pa.us
EnterpriseDB http://www.enterprisedb.com
+ If your life is a hard drive, Christ can be your backup. +
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Reply to all the recipients using the --to and --cc options:
reply via email
To: pgsql-performance@postgresql.org
Cc: pgman@candle.pha.pa.us, stefan@kaltenbrunner.cc, zhouqq@cs.toronto.edu, pgsql-hackers@postgresql.org
Subject: Re: Test request for Stats collector performance improvement
In-Reply-To: <200606161624.k5GGO3N03466@candle.pha.pa.us>
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox